function [t,y] = rk4ode(func, a, b, y0, h);
% solution of 1st order ODE using Runge-Kutta 4th order
% with constant step size
%
%      dy/dt = func(t,y)
%
% USAGE:  [t,y] = rk4ode(func,a,b,y0,h)
%
% input  func    = name of external function to evaluate the RHS
%                  of the ODE
%        a, b    = limits of integration
%        y0      = initial condition
%        h       = stepsize
%
% output [t, y]  = solution vectors

t = [a];
y = [y0];
i = 1;

while t(i) < b

   k1 = feval(func, t(i)    , y(i)       );
   k2 = feval(func, t(i)+h/2, y(i)+k1*h/2);
   k3 = feval(func, t(i)+h/2, y(i)+k2*h/2);
   k4 = feval(func, t(i)+h  , y(i)+k3*h  );

   i = i+1;
   t(i) = t(i-1) + h;

   y(i) = y(i-1) + (k1 + 2*k2 + 2*k3 + k4)*h/6;

end
